"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.gitlab.v1.instance_pb2
import yandex.cloud.gitlab.v1.instance_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class InstanceServiceStub:
    """InstanceService provides methods for managing GitLab instances."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.GetInstanceRequest,
        yandex.cloud.gitlab.v1.instance_pb2.Instance,
    ]
    """Returns the specified GitLab instance."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.ListInstancesRequest,
        yandex.cloud.gitlab.v1.instance_service_pb2.ListInstancesResponse,
    ]
    """Retrieves the list of GitLab instances in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.CreateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new GitLab instance in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.UpdateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates GitLab instance."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.DeleteInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified GitLab instance."""

    Start: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.StartInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified GitLab instance."""

    Stop: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.StopInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified GitLab instance."""

class InstanceServiceAsyncStub:
    """InstanceService provides methods for managing GitLab instances."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.GetInstanceRequest,
        yandex.cloud.gitlab.v1.instance_pb2.Instance,
    ]
    """Returns the specified GitLab instance."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.ListInstancesRequest,
        yandex.cloud.gitlab.v1.instance_service_pb2.ListInstancesResponse,
    ]
    """Retrieves the list of GitLab instances in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.CreateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a new GitLab instance in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.UpdateInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates GitLab instance."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.DeleteInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified GitLab instance."""

    Start: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.StartInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts the specified GitLab instance."""

    Stop: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.gitlab.v1.instance_service_pb2.StopInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Stops the specified GitLab instance."""

class InstanceServiceServicer(metaclass=abc.ABCMeta):
    """InstanceService provides methods for managing GitLab instances."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.gitlab.v1.instance_service_pb2.GetInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.gitlab.v1.instance_pb2.Instance, collections.abc.Awaitable[yandex.cloud.gitlab.v1.instance_pb2.Instance]]:
        """Returns the specified GitLab instance."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.gitlab.v1.instance_service_pb2.ListInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.gitlab.v1.instance_service_pb2.ListInstancesResponse, collections.abc.Awaitable[yandex.cloud.gitlab.v1.instance_service_pb2.ListInstancesResponse]]:
        """Retrieves the list of GitLab instances in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.gitlab.v1.instance_service_pb2.CreateInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a new GitLab instance in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.gitlab.v1.instance_service_pb2.UpdateInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates GitLab instance."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.gitlab.v1.instance_service_pb2.DeleteInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified GitLab instance."""

    @abc.abstractmethod
    def Start(
        self,
        request: yandex.cloud.gitlab.v1.instance_service_pb2.StartInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts the specified GitLab instance."""

    @abc.abstractmethod
    def Stop(
        self,
        request: yandex.cloud.gitlab.v1.instance_service_pb2.StopInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Stops the specified GitLab instance."""

def add_InstanceServiceServicer_to_server(servicer: InstanceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/project.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/project.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/speechsense/v1/project.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x02\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rconnection_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\ncreated_by\x18\x05 \x01(\t\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bmodified_by\x18\x07 \x01(\t\x12/\n\x0bmodified_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x07\x66ilters\x18\t \x03(\x0b\x32(.yandex.cloud.speechsense.v1.FieldFilter\"/\n\x0b\x46ieldFilter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\x0b\x66ield_value\x18\x02 \x01(\tB|\n\x1fyandex.cloud.api.speechsense.v1B\x0cProjectProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.project_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\014ProjectProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_PROJECT']._serialized_start=108
  _globals['_PROJECT']._serialized_end=384
  _globals['_FIELDFILTER']._serialized_start=386
  _globals['_FIELDFILTER']._serialized_end=433
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/point_of_presence_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/point_of_presence_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.cic.v1 import point_of_presence_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_point__of__presence__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/cic/v1/point_of_presence_service.proto\x12\x13yandex.cloud.cic.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a+yandex/cloud/cic/v1/point_of_presence.proto\"G\n\x19GetPointOfPresenceRequest\x12*\n\x14point_of_presence_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"}\n\x1bListPointOfPresencesRequest\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x01\x10\x02\"y\n\x1cListPointOfPresencesResponse\x12@\n\x12point_of_presences\x18\x01 \x03(\x0b\x32$.yandex.cloud.cic.v1.PointOfPresence\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbf\x02\n\x16PointOfPresenceService\x12\x94\x01\n\x03Get\x12..yandex.cloud.cic.v1.GetPointOfPresenceRequest\x1a$.yandex.cloud.cic.v1.PointOfPresence\"7\x82\xd3\xe4\x93\x02\x31\x12//cic/v1/pointOfPresences/{point_of_presence_id}\x12\x8d\x01\n\x04List\x12\x30.yandex.cloud.cic.v1.ListPointOfPresencesRequest\x1a\x31.yandex.cloud.cic.v1.ListPointOfPresencesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/cic/v1/pointOfPresencesBV\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.point_of_presence_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _globals['_GETPOINTOFPRESENCEREQUEST'].fields_by_name['point_of_presence_id']._loaded_options = None
  _globals['_GETPOINTOFPRESENCEREQUEST'].fields_by_name['point_of_presence_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPOINTOFPRESENCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPOINTOFPRESENCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTPOINTOFPRESENCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPOINTOFPRESENCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTPOINTOFPRESENCESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTPOINTOFPRESENCESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_POINTOFPRESENCESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_POINTOFPRESENCESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0021\022//cic/v1/pointOfPresences/{point_of_presence_id}'
  _globals['_POINTOFPRESENCESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_POINTOFPRESENCESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\032\022\030/cic/v1/pointOfPresences'
  _globals['_GETPOINTOFPRESENCEREQUEST']._serialized_start=182
  _globals['_GETPOINTOFPRESENCEREQUEST']._serialized_end=253
  _globals['_LISTPOINTOFPRESENCESREQUEST']._serialized_start=255
  _globals['_LISTPOINTOFPRESENCESREQUEST']._serialized_end=380
  _globals['_LISTPOINTOFPRESENCESRESPONSE']._serialized_start=382
  _globals['_LISTPOINTOFPRESENCESRESPONSE']._serialized_end=503
  _globals['_POINTOFPRESENCESERVICE']._serialized_start=506
  _globals['_POINTOFPRESENCESERVICE']._serialized_end=825
# @@protoc_insertion_point(module_scope)
